aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-x11.c
diff options
context:
space:
mode:
authorDario Lombardo <lomato@gmail.com>2014-06-17 17:49:26 +0200
committerAnders Broman <a.broman58@gmail.com>2014-06-18 14:20:32 +0000
commit021e7afc9fcba09094d0e2143cc434a34e3b09dc (patch)
treefa0f1cf92d649f2773d63ba35f67c8722e31fb38 /epan/dissectors/packet-x11.c
parent246fe2ca4c67d8c98caa84e2f57694f6322e2f96 (diff)
Fixup: tvb_ensure_length_remaining -> tvb_ensure_captured_length_remaining
Change-Id: I0228f3b6b7067bc0ce51f9d359f99fd18feb2b66 Reviewed-on: https://code.wireshark.org/review/2378 Reviewed-by: Anders Broman <a.broman58@gmail.com>
Diffstat (limited to 'epan/dissectors/packet-x11.c')
-rw-r--r--epan/dissectors/packet-x11.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/epan/dissectors/packet-x11.c b/epan/dissectors/packet-x11.c
index 338d61b975..a3e8494cbe 100644
--- a/epan/dissectors/packet-x11.c
+++ b/epan/dissectors/packet-x11.c
@@ -4372,13 +4372,13 @@ static void dissect_x11_requests(tvbuff_t *tvb, packet_info *pinfo,
while (tvb_reported_length_remaining(tvb, offset) != 0) {
/*
* We use "tvb_ensure_length_remaining()" to make sure there
* actually *is* data remaining.
*
* This means we're guaranteed that "length_remaining" is
* positive.
*/
- length_remaining = tvb_ensure_length_remaining(tvb, offset);
+ length_remaining = tvb_ensure_captured_length_remaining(tvb, offset);
/*
* Can we do reassembly?
@@ -4724,13 +4724,13 @@ dissect_x11_replies(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
offset = 0;
while (tvb_reported_length_remaining(tvb, offset) != 0) {
/*
* We use "tvb_ensure_length_remaining()" to make sure there
* actually *is* data remaining.
*
* This means we're guaranteed that "length_remaining" is
* positive.
*/
- length_remaining = tvb_ensure_length_remaining(tvb, offset);
+ length_remaining = tvb_ensure_captured_length_remaining(tvb, offset);
/*
* Can we do reassembly?
@@ -4372,13 +4372,13 @@ static void dissect_x11_requests(tvbuff_t *tvb, packet_info *pinfo,
while (tvb_reported_length_remaining(tvb, offset) != 0) {
/*
- * We use "tvb_ensure_length_remaining()" to make sure there
+ * We use "tvb_ensure_captured_length_remaining()" to make sure there
* actually *is* data remaining.
*
@@ -4724,13 +4724,13 @@ dissect_x11_replies(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
while (tvb_reported_length_remaining(tvb, offset) != 0) {
/*
- * We use "tvb_ensure_length_remaining()" to make sure there
+ * We use "tvb_ensure_captured_length_remaining()" to make sure there
* actually *is* data remaining.
*